@@ -1,6 +1,6 @@
 from .dft import get_grad, get_n_total, orth, solve_poisson
 from .energies import get_E
-from .xc import lda_slater_x, lda_vwn_c
+from .xc import lda_chachiyo_c, lda_slater_x
 
 
 def scf_step(scf):
@@ -8,17 +8,16 @@ def scf_step(scf):
     scf.Y = orth(scf.atoms, scf.op, scf.W)
     scf.n = get_n_total(scf.atoms, scf.op, scf.Y)
     scf.phi = solve_poisson(scf.atoms, scf.op, scf.n)
-    scf.exc = lda_slater_x(scf.n)[0] + lda_vwn_c(scf.n)[0]
-    scf.vxc = lda_slater_x(scf.n)[1] + lda_vwn_c(scf.n)[1]
+    x, c = lda_slater_x(scf.n), lda_chachiyo_c(scf.n)
+    scf.exc = x[0] + c[0]
+    scf.vxc = x[1] + c[1]
     return get_E(scf)
 
 
-def sd(scf, Nit, beta=1e-5, etol=1e-6):
-    '''
-        Steepest descent minimization algorithm.
-        An SCF algorithm.
-        Latex: List. 3.21
-               Fig. 3.2
+def sd(scf, Nit, etol=1e-6, beta=1e-5):
+    '''Steepest descent minimization algorithm.
+    Thesis: List. 3.21
+            Fig. 3.2
     '''
     Elist = []
 
